************************************
************************************
*This file is a modification of code by Bettinger, Evans, Pope

****
*Input

*This file takes as input "99.dta" from Betting, Evans, Pope
*Instructions for creating "99.dta" are found in that reference
*The input file should be saved in the working directory

****
*Output


*This file outputs "ACT_99_data_to_csv.csv" which is used for estimating 
*Post-Nonparametric Double Selection in Matlab
*This file also produces basic summary statistics 
*and regression results (without model selection)


clear all

set mem 300M
set mat 800



use 99data.dta

keep if cohort99 == 1
drop if act_comp == .
drop if dropout_yr1 == .
drop if gpa99 == 0 | gpa00 == 0

drop dc_* state cohort99 act flag_no _merg*

tab hsgpa, gen(hsgpa_dum)
tab campus, gen(campus_dum)
tab race, gen(race_dum)



*****Summary Statistics****
*Table 1
sum gpa99 gpa00 dropout_yr1 dropout_yr3 hsgpa act_comp act_math act_eng act_read act_science male
gen other = 0
replace other = 1 if race == "AI" | race == "NR" | race == "UK"
gen black = 0
replace black = 1 if race == "BL"
gen white = 0
replace white = 1 if race == "WH"
gen asian = 0
replace asian = 1 if race == "AS"
gen hispanic = 0
replace hispanic = 1 if race == "HS"

sum white black hispanic asian other




***Do schools admit students based on the composite?

gen usn_pct = .
replace usn_pct = .3009 if campus == "AKRN"
replace usn_pct = .0149 if campus == "CNTL"
replace usn_pct = .2180 if campus == "CLEV"
replace usn_pct = .7975 if campus == "MIAM"
replace usn_pct = .7099 if campus == "OHUN"
replace usn_pct = .2351 if campus == "TLDO"
replace usn_pct = .1906 if campus == "YNGS"
replace usn_pct = .5462 if campus == "BGSU"
replace usn_pct = .5314 if campus == "CINC"
replace usn_pct = .2754 if campus == "KENT"
replace usn_pct = .6620 if campus == "OHSU"
replace usn_pct = .0269 if campus == "SHAW"
replace usn_pct = .0585 if campus == "WSUN"





**A few additional variables that will be good to have for the figures below
gen minority = 0
replace minority = 1 if race == "AI" | race == "BL" | race == "AS" | race == "HS"

recode major1 (110101/119999=1), gen(cs)
recode cs (2/max=0)
recode major1 (140101/159999=1), gen(eng)
recode eng (2/max=0)
recode major1 (260101/269999=1), gen(bio)
recode bio (2/max=0)
recode major1 (270101/279999=1), gen(math)
recode math (2/max=0)
recode major1 (300101 300601 300801 301001 301501=1), gen(interdis)
recode interdis (2/max=0)
recode major1 (400101/400401=1), gen(phys_sci)
recode phys_sci (2/max=0)
recode major1 (400501/400599=1), gen(chem)
recode chem (2/max=0)
recode major1 (400601/400699=1), gen(geo)
recode geo (2/max=0)
recode major1 (400701/400799=1), gen(earth)
recode earth (2/max=0)
recode major1 (400801/409999=1), gen(phys)
recode phys (2/max=0)
recode major1 (410101/419999=1), gen(techs)
recode techs (2/max=0)

gen maj_sci=0
replace maj_sci=1 if cs==1 | eng==1 | bio==1 | math==1 | interdis==1 | phys_sci==1 | chem==1 | geo==1 | earth==1 | phys==1 | techs==1
quietly tab maj_sci


********************
***Regressions******
********************


*Table 2
reg gpa99 act_comp, robust 
reg gpa99 act_math act_eng act_read act_science, robust 
reg gpa99 act_math act_eng act_read act_science campus_dum* hsgpa_dum* male race_dum*, robust 
areg gpa99 act_math act_eng act_read act_science campus_dum* hsgpa_dum* male race_dum*, absorb(major1) robust 

*With major dummies


reg gpa99 act_math act_eng act_read act_science campus_dum* hsgpa_dum* male race_dum* cs eng bio math interdis phys_sci chem geo earth phys techs, robust 


*Generate Quadratics
gen act_math_sq = act_math^2
gen act_science_sq = act_science^2
gen act_eng_sq = act_eng^2
gen act_read_sq = act_read^2

*Quadratic Regressions
reg gpa99 act_math* act_eng* act_read* act_science*, robust 
reg gpa99 act_math* act_eng* act_read* act_science* campus_dum* hsgpa_dum* male race_dum* cs eng bio math interdis phys_sci chem geo earth phys techs, robust 

gen byte used_final=e(sample)


outsheet gpa99 act_math act_eng act_read act_science campus_dum* hsgpa_dum* male race_dum* cs eng bio math interdis phys_sci chem geo earth phys techs using ACT_99_data_to_csv.csv if used_final == 1, comma replace













