function [unique_values] = get_lasso_values_or(iterateMat, matrix, alpha, c_tau, logfile)
    %   get_lasso_values_or: This runs a lasso for all columns of the iterateMat input Argument.
    %   After each lasso it checks for any row which has at least one True.

    if nargin < 5
        logfile = 'lassotime.log';
    end
    
    %% initialize
    nrColumns = size(iterateMat, 2);
    if numel(alpha) ~= nrColumns
        alpha = repmat(alpha(1), nrColumns, 1);
    end
    
    printcmd = sprintf('Lasso %%0%dd completed in %%0.3f seconds', numel(num2str(nrColumns)));

    normLoadHdl = @(x) matrix ./ sqrt(sum((x .* matrix) .^ 2 ./ size(matrix, 1)));
    lambda = 2 .* c_tau .* sqrt(1 ./ size(matrix, 1)) .* norminv(1 - alpha ./ size(matrix, 2));

    %% run Lassos
    fprintf('Starting Lasso regression (log file "./%s")\n', logfile);
    
    unique_values = sparse(size(matrix, 2), 1);
    for curColumn = 1:nrColumns
        timer = tic();
        curMat = normLoadHdl(iterateMat(:, curColumn));
        temp_values = sparse(lasso(curMat, iterateMat(:, curColumn), 'Lambda', lambda(curColumn)) > 0.01);
        unique_values = unique_values | temp_values;
        system(['echo "', sprintf(printcmd, curColumn, toc(timer)), '" >> ', logfile]);
    end
end
