function [orData, andData, hwData, VUnique] = interaction_expansion_act(X)

    %% initialize
    [n, p] = size(X);
    V = bi2de(X);
    VUnique = unique(V);

    %% create all combinations
    pVec = 1:p;
    [combVecA, combVecB, combVecC] = meshgrid(pVec, pVec, pVec);
    allCombs = [combVecA(:), combVecB(:), combVecC(:)];
    allCombs = allCombs(allCombs(:, 1) <= allCombs(:, 2) & allCombs(:, 2) <= allCombs(:, 3), :);
    nCombs = size(allCombs, 1);
    
    %% preallocation
    % orData, andData, hwData --> previously W, WW and WWW
    orData = zeros(n, nCombs);   % "or" interaction expansion
    andData = orData;                        % "and" interaction expansion
    hwData = orData;                         % Hadamard-Walsh Basis
    
    idxOr = zeros(nCombs, 1);
    idxAnd = idxOr;
    idxHw = idxOr;

    newtimer = tic();
    parfor row = 1:size(allCombs, 1)
        curColumns = X(:, unique(allCombs(row, :)));

        N_temp = any(curColumns, 2);  
        NN_temp = all(curColumns, 2);
        NNN_temp = (-1) .^ sum(curColumns, 2);

        if std(N_temp) > .05
            idxOr(row) = 1;
            orData(:, row) = N_temp;
        end
        
        if std(NN_temp) > .05
            idxAnd(row) = 1;
            andData(:, row) = NN_temp;
        end

        if std(NNN_temp) > .05 * sqrt(2)
            idxHw(row) = 1;
            hwData(:, row) = NNN_temp;
        end
    end
    toc(newtimer)

    orData = orData(:, logical(idxOr.'));
    andData = andData(:, logical(idxAnd.'));
    hwData = hwData(:, logical(idxHw.'));    
    
    %% Matrix handling
    % This would be the handling without a for loop unfortunately, it requests ca 30GB of Memory
    %
    % unfortunately not working --> needs 19.5GB Memory when computed via GPU
    
%     matTimer = tic();
%     combinationMatrix = gpuArray(reshape(X(:, allCombs.'), [], size(allCombs, 2), nCombs));
% 
%     % or interaction
%     orTemp = permute(any(combinationMatrix, 2), [1, 3, 2]);
%     orData = gather(orTemp(:, logical(std(orTemp) > 0.05)));
%     clear orTemp
%     fprintf('Elapsed time till "or" finished: %.4f\n', toc(matTimer));
%     
%     % and interaction
%     andTemp = permute(all(combinationMatrix, 2), [1, 3, 2]);
%     andData = gather(andTemp(:, logical(std(andTemp) > 0.05)));
%     clear andTemp
%     fprintf('Elapsed time till "and" finished: %.4f\n', toc(matTimer));
%     
%     % Hadamard-Walsh Basis
%     hwTemp = permute((-1) .^ sum(combinationMatrix, 2), [1, 3, 2]);
%     hwData = gather(hwTemp(:, logical(std(hwTemp) > 0.05 * sqrt(2))));
%     clear hwTemp
%     fprintf('Elapsed time till "HW basis" finished: %.4f\n', toc(matTimer));
    
end