function [p, t] = myspline(K, x)
    % Cubic Spline Basis

    spline_order = 3;
    c1 = 1;
    c2 = .5;
    tmax = quantile(abs(x), .95);
    tmin = -tmax;

    delta0 = abs((K + 1) ./ 2 - (1:K)).';
    delta = (c1 + c2 * delta0) / (sum(c1 + c2 * delta0)) * (tmax - tmin);
    t = cumsum([tmin; delta]);

    B = bspline1(t, spline_order + 1);
    p = cell(K, 1);
    
    for k=1:K-3
        p{k} = B{k, spline_order + 1};
    end
    
    if K > 2
        p{K - 2} = @(x) x;
    end
    if K > 1
        p{K - 1} = @(x)x .^ 2 / 2;
    end
    
    p{K} = @(x) x .^ 3 / 6;

end

