function status = prepareACTdata(srcfile, datafile)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %
    % Estimation file: "Estimation and Inference in Additively Separable
    % Conditional Expectation Models with a High Dimensional Component"
    %
    % ACT Example
    %
    % y = g0(x) + h0(z) + e
    %
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %% TODO: for testing deactivate max array size
    s = settings;
    s.matlab.desktop.workspace.ArraySizeLimitEnabled.PersonalValue = false;

    %% extract data if .mat file is already existing
    [path, ~, ~] = fileparts(datafile);
    mkdir(path);
    logfile = fullfile(path, 'prepro_lasso_time.log');
    resultfile = 'ws_prepro_finished.mat';
    
    if isfolder(path) && isfile(fullfile(path, resultfile))
        status = 1;
        return
    end
        
    if ~isfile(datafile)
        act_stata2mat_data_extraction(srcfile, datafile);
    end
    
    %% import data
    load(datafile, 'Z_Controls', 'Y', 'X1', 'X2', 'X3', 'X4');
    Z_Controls = single(Z_Controls); %#ok
    
    %% prepare variables
    nrElements = numel(Y);
    allYX = [single(Y), single(X1), single(X2), single(X3), single(X4)];
    clear Y X1 X2 X3 X4
    
    normYX = allYX - mean(allYX);
    nrColumns = size(allYX, 2);
    clear allYX
    
    scoreYX = zscore(normYX);
    scoreControls = (Z_Controls - mean(Z_Controls)) ./ std(Z_Controls);
    clear Z_Controls
    
    %% Lasso first stage
    s_lasso_rf = get_lasso_values_or(scoreYX(:, 1), scoreControls, .1, 1.01, logfile);
    s_lasso_fs = get_lasso_values_or(scoreYX(:, 2:end), scoreControls, .05, 1.01, logfile);
    
    %% Prepare original values
    K_est = generate_p_ACT(normYX(:, 1), normYX(:, 2:end), scoreControls(:, s_lasso_rf ~= 0));
    P = zeros(nrElements, (nrColumns - 1) .* K_est, 'single');

    for curIter = 2:nrColumns
        fHandles = generate_p_fixed_K(normYX(:, curIter), K_est);
        for k = 1:K_est
            P(:, (curIter - 2) .* K_est + k) = fHandles{k}(normYX(:, curIter));
        end
    end
    p = num2cell(P, 1);
    zeta = P \ scoreControls;

    save(fullfile(path, 'ws_prepro.mat'), '-v7.3');
    
    %% Lasso regression
    s_fs_all = get_lasso_values_or(zscore(P), scoreControls, .05 ./ size(P, 2), 1.01, logfile);
    iterateMatrix = zscore(P * zeta);
    
    save(fullfile(path, resultfile), '-v7.3');
    clear

    %% return status
    status = 0;
end