function runAllOnInstance(datafile, outputDir)
    
    [path, ~, ~] = fileparts(datafile);
    if nargin < 3
        outputDir = path;
    end

    mkdir(outputDir);

    %% load data for iterations
    loader = load(datafile, 'iterateMatrix', 'scoreControls', 'nrColumns');
    iterateMatrix = loader.iterateMatrix;
    scoreControls = loader.scoreControls;
    nrColumns = loader.nrColumns - 1;
    clear loader
    
    %% define variables
    alpha = 0.5 ./ nrColumns;
    c_tau = 1.01;
    normLoadHdl = @(x) scoreControls ./ sqrt(sum((x .* scoreControls) .^ 2 ./ size(scoreControls, 1)));
    lambda = 2 .* c_tau .* sqrt(1 ./ size(scoreControls, 1)) .* norminv(1 - alpha ./ size(scoreControls, 2));
    
    %% setup logger
    iterations = 1:size(iterateMatrix, 2);
    logfile = fullfile(outputDir, sprintf('lassotime_%d.log', max(iterations)));
    printcmd = sprintf('Lasso %%0%dd completed in %%0.3f seconds (%%d%%)', numel(num2str(max(iterations))));
    
    %% run lasso for each iteration
    fprintf('Starting Lasso regression (log file "./%s")\n', logfile);
    
    s_lasso = sparse(size(scoreControls, 2), 1);
    for curIter = 1:numel(iterations)
        timer = tic();
        curMat = normLoadHdl(iterateMatrix(:, curIter));
        temp_lasso = sparse(lasso(curMat, iterateMatrix(:, curIter), 'Lambda', lambda) > 0.01);
        progress = round(iterations(curIter) .* 100 ./ max(iterations));
        system(['echo "', sprintf(printcmd, iterations(curIter), toc(timer), progress), '" >> ', logfile]);
    
        s_lasso = s_lasso | temp_lasso;
    end
    
    save(fullfile(outputDir, sprintf('result_lasso_iter_%d-%d.mat', min(iterations), max(iterations))), 's_lasso', '-v7.3');
end