
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Simulation for "Estimation and Inference in Additively Separable
%Conditional Expectation Models with a High Dimensional Component"
%y = g0(x) + h0(z) + e

%Comparison of Span (also called Blanket in this code) first stage to other methods and dictionaries


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Display Start time
disp('Simulation start time:')
disp(datetime('now'))

%Simulation Parameters
rng(1);
tic
n_vec = 100:50:500;
sim_id_max=length(n_vec);
L_id_max=2;
sim_max=1000;

for L_id = 2
    
    
    
%Preassign Output Matrices
 
Vhat_Oracle = zeros(sim_max,1);
Vhat_Naive = zeros(sim_max,1);
Vhat_OLS = zeros(sim_max,1);
Vhat_Blanket = zeros(sim_max,1);
ub_TU = zeros(sim_max,1);
lb_TU = zeros(sim_max,1);
 

thetahat_Oracle = zeros(sim_max,1);
thetahat_Naive = zeros(sim_max,1);
thetahat_OLS = zeros(sim_max,1);
thetahat_Blanket = zeros(sim_max,1);


ISE_Oracle = zeros(sim_max,1);
ISE_Naive = zeros(sim_max,1);
ISE_OLS = zeros(sim_max,1);
ISE_Blanket = zeros(sim_max,1);



theta0=zeros(sim_max,1);


StDev_Blanket=zeros(sim_id_max,1);
StDev_Naive=zeros(sim_id_max,1);
StDev_Oracle=zeros(sim_id_max,1);
StDev_OLS=zeros(sim_id_max,1);
StDev_TU=zeros(sim_id_max,1);

Bias_Blanket=zeros(sim_id_max,1);
Bias_Naive=zeros(sim_id_max,1);
Bias_Oracle=zeros(sim_id_max,1);
Bias_OLS=zeros(sim_id_max,1);
Bias_TU=zeros(sim_id_max,1);

rej_Blanket=zeros(sim_id_max,1);
rej_Naive=zeros(sim_id_max,1);
rej_Oracle=zeros(sim_id_max,1);
rej_OLS=zeros(sim_id_max,1);
rej_TU=zeros(sim_id_max,1);

Length_Blanket=zeros(sim_id_max,1);
Length_Naive=zeros(sim_id_max,1);
Length_Oracle=zeros(sim_id_max,1);
Length_OLS=zeros(sim_id_max,1);
Length_TU=zeros(sim_id_max,1);

MISE_OLS=zeros(sim_id_max,1);
MISE_Oracle=zeros(sim_id_max,1);
MISE_Naive=zeros(sim_id_max,1);
MISE_Blanket=zeros(sim_id_max,1);
MISE_TU=zeros(sim_id_max,1);


K_OLS=zeros(sim_max,1);
K_Oracle=zeros(sim_max,1);
K_Naive=zeros(sim_max,1);
K_Blanket=zeros(sim_max,1);
K_TU=zeros(sim_max,1);

L_OLS=zeros(sim_max,1);
L_Oracle=zeros(sim_max,1);
L_Naive=zeros(sim_max,1);
L_Blanket=zeros(sim_max,1);
L_TU=zeros(sim_max,1);

Track_K_OLS=zeros(sim_id_max,1);
Track_K_Oracle=zeros(sim_id_max,1);
Track_K_Naive=zeros(sim_id_max,1);
Track_K_Blanket=zeros(sim_id_max,1);
Track_K_TU=zeros(sim_id_max,1);

Track_L_OLS=zeros(sim_id_max,1);
Track_L_Oracle=zeros(sim_id_max,1);
Track_L_Naive=zeros(sim_id_max,1);
Track_L_Blanket=zeros(sim_id_max,1);
Track_L_TU=zeros(sim_id_max,1);

%Loop over sample sizes
for sim_id = 1:sim_id_max

 for nsim = 1:sim_max   
     %g0 Design
g0=@(x)   10*sin(x/10)-.5*sin(4*pi*x.*4.^(-x.^2));
n=n_vec(sim_id);
sigma_e=1;
sigma_v=1;
if L_id == 1, cL=.5; else cL=2; end
L=floor(n*cL);
s0=6;
gamma0=((.75).^(1:(L)).*abs((1:L)<=s0))';
beta0h = .5*((-.65).^(0:(L-1)).*abs((1:L)<=s0))'; %beta0h(6)=.25;
h0=@(z) z* beta0h ;   


    
    %Generate Data  
        v=randn(n,1)*sigma_v;
        vv=rand(n,1)/2;
        S = chol(toeplitz((.25).^(0:(L-1))));
        z=randn(n,L)*S;
        eta0=zeros(L,1); 
        
        %for jj=floor(s0/2):s0 
        %    eta0(jj) = .5;
        %end
        eta0(s0)=1;
        
        vvv = randn(n,1);
        %x= z*gamma0 + v;
        a_stair=12;w_stair=2.5;h_stair=.25;
        stair_step = @(x,h,w,a) h*( (tanh(a*x/w -  a*floor(x/w) - a*.5 ))./ (2*tanh(a /2)) + .5 + floor(x/w) ); 
        %figure, plot(-10:.1:10,stair_step((-10:.1:10),h_stair,w_stair,a_stair))
        
        
        %x_hmtpy=@(x,t)x.*t + stair_step(x,h_stair,w_stair,a_stair).*(1-t);
        %x= x_hmtpy(z*gamma0 + v,norminv(z*eta0));
        
        
        
        zz=-2*z*gamma0 + 1*v;
        tt=normcdf(z*eta0*10);
 x = 1.5*(.1*v+ .25 + -.5 *( (5*stair_step(zz,h_stair,w_stair,a_stair)+.5).*tt +  (5*stair_step(.5*zz.*abs(zz).^.25+1,h_stair,w_stair,a_stair)).*(1-tt)  )   );

        %x = (5*stair_step(zz,h_stair,w_stair,a_stair)-.35).*abs(tt<.05) +  (5*stair_step(zz,h_stair,w_stair,a_stair)+.25).*(1-tt).*abs(tt>.95) + z.*abs(tt<.95 & tt>.05);
        e=randn(n,1)*sigma_e.*.5.*(exp(.5*z*(.75.^((L-1):(-1):0)')));
        y = g0(x) + h0(z) + e;
        
        %figure, plot(z(:,6),x,'o')
        
        
        %Generate functional of interest   
        x_a_unif = norminv(.01:.01:.99)';
        theta0(nsim)=ave_deriv(g0,x_a_unif);
    
    
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %ESTIMATION
        
        %z dictionary definition
        Q=z;

        %Lasso Steps
        [S_lasso_RF,~,~,~, ~, ~]=lasso_hetero(y,Q,.05,1.01); 
          
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Construct dictionaries

        
        %Oracle Dictionary
        [p_Oracle,K_Oracle(nsim)]= generate_p(y,x,Q(:,1:s0));
        P_Oracle=[];for k=1:K_Oracle(nsim), P_Oracle=[P_Oracle,p_Oracle{k}(x)]; end, Q_Oracle = z(:,1:s0); %#ok
    
        %OLS Dictionary
        if L<n
        [p_OLS,K_OLS(nsim)]= generate_p(y,x,Q);
        P_OLS=[];for k=1:K_OLS(nsim), P_OLS=[P_OLS,p_OLS{k}(x)]; end, Q_OLS = Q; %#ok
        end

        %Post-Selection Dictionaries
        [p_RF,K_RF]= generate_p(y,x,z(:,S_lasso_RF));
        P_RF=[];for k=1:K_RF, P_RF=[P_RF,p_RF{k}(x)];  end, Q_RF = Q(:,S_lasso_RF); %#ok
        p_TU = p_RF; P_TU = P_RF;  K_TU(nsim) = K_RF;
        p_Naive = p_RF; P_Naive = P_RF;  K_Naive(nsim) = K_RF;
        p_Blanket = p_RF; P_Blanket = P_RF;  K_Blanket(nsim) = K_RF;
        p_PD = p_RF; P_PD = P_RF;
        
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-1
    [S_lasso_FS_1,~,~,~, ~, ~]=lasso_hetero(x,Q,.05,1.01); 
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-2
    S_lasso_FS_2=[];
    
    
    for k = 1:K_RF
        [S_Simple_temp,~,~,~, ~, ~]=lasso_hetero(P_RF(:,k),Q,.05/K_RF,1.01 ); 
        if isempty(S_lasso_FS_2), S_lasso_FS_2 = S_Simple_temp;
        else
        S_lasso_FS_2 = S_lasso_FS_2 | S_Simple_temp ;
        end
    end
    

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-3
    S_lasso_FS_3=[];
    
    zeta = pinv(P_RF'*P_RF)*P_RF'*Q;
    for j = 1:L
        [S_Blanket_temp,~,~,~, ~, ~]=lasso_hetero(P_RF*zeta(:,j),Q,.05/K_RF,1.01 ); 
        if isempty(S_lasso_FS_3), S_lasso_FS_3 = S_Blanket_temp;
        else
        S_lasso_FS_3 = S_lasso_FS_3 | S_Blanket_temp ;
        end
    end
    %}
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Form Unions
    S_lasso_RF = find(S_lasso_RF ~=0);
    S_lasso_FS_1 = find(S_lasso_FS_1 ~=0);
    S_lasso_FS_2 = find(S_lasso_FS_2 ~=0);
    S_lasso_FS_3 = find(S_lasso_FS_3 ~=0);
    S_lasso_FS_12 = union(S_lasso_FS_1, S_lasso_FS_2); 
    S_lasso_FS = union(S_lasso_FS_12, S_lasso_FS_3); 
    S_lasso_PD = union(S_lasso_RF,S_lasso_FS_12);
    S_lasso_Blanket = union(S_lasso_RF,S_lasso_FS);
    
    
    Q_PD=Q(:,S_lasso_PD);
    Q_Blanket=Q(:,S_lasso_Blanket);
    Q_Naive=Q(:,S_lasso_RF);

    %Record values of number chosen
    
    L_OLS(nsim)=L;
    L_Oracle(nsim)=s0;
    L_Naive(nsim)=size(Q_Naive,2);
    L_Blanket(nsim)=size(Q_Blanket,2);
    L_TU(nsim)=size(Q_Naive,2)+1;
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Post Model Selection Estimation
    
    %OLS
    if L < n
    [ghat_OLS, thetahat_OLS(nsim), Vhat_OLS(nsim)] = nonpar_simple(y,x,p_OLS,K_OLS(nsim),Q_OLS);
    end

    %Oracle -- Knowing support
    [ghat_Oracle, thetahat_Oracle(nsim), Vhat_Oracle(nsim)] = nonpar_simple(y,x,p_Oracle,K_Oracle(nsim),Q_Oracle);

    %Blanket Post - Double Selection
    [ghat_Blanket,thetahat_Blanket(nsim),Vhat_Blanket(nsim)] = nonpar_simple(y,x,p_Blanket,K_Blanket(nsim),Q_Blanket); 
    
    %Post - Single Selection I
    [ghat_Naive,thetahat_Naive(nsim), Vhat_Naive(nsim)] = nonpar_simple(y,x,p_Naive,K_Naive(nsim),Q_Naive); 
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Record ISE
    if L<n, ISE_OLS(nsim) = mean((ghat_OLS(x) - g0(x)).^2); end
    ISE_Oracle(nsim) = mean((ghat_Oracle(x) - g0(x)).^2);
    ISE_Blanket(nsim) = mean((ghat_Blanket(x) - g0(x)).^2);
    ISE_Naive(nsim) = mean((ghat_Naive(x) - g0(x)).^2);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %TU
    max_TU_search = 2*s0;
    ub_TU_vec = zeros(max_TU_search,1);
    lb_TU_vec = zeros(max_TU_search,1);
    for jj= 1:max_TU_search
        if ~ismember(jj,S_lasso_RF)
           [~,thetahat_Naive_TU, Vhat_Naive_TU] = nonpar_simple(y,x,p_Naive,K_Naive(nsim),[z(:,jj),Q_Naive]);
        else
            [~,thetahat_Naive_TU, Vhat_Naive_TU] = nonpar_simple(y,x,p_Naive,K_Naive(nsim),Q_Naive);
        end
           ub_TU_vec(jj) = thetahat_Naive_TU + 1.96*sqrt(Vhat_Naive_TU/n);
           lb_TU_vec(jj) = thetahat_Naive_TU - 1.96*sqrt(Vhat_Naive_TU/n);
    end 
    lb_TU(nsim) = min(lb_TU_vec);  ub_TU(nsim) = max(ub_TU_vec);

    
    
    

end


StDev_Blanket(sim_id) = std(theta0 - thetahat_Blanket);
Bias_Blanket(sim_id) = mean(theta0 - thetahat_Blanket);
rej_Blanket(sim_id) = mean( abs(thetahat_Blanket - theta0)>1.96*sqrt(Vhat_Blanket/n));
Length_Blanket(sim_id) = mean(1.96*sqrt(Vhat_Blanket/n));
MISE_Blanket(sim_id) = mean(ISE_Blanket);
Track_K_Blanket(sim_id) = mean(K_Blanket);
Track_L_Blanket(sim_id) = mean(L_Blanket);


StDev_Naive(sim_id) = std(theta0 - thetahat_Naive);
Bias_Naive(sim_id) = mean(theta0 - thetahat_Naive);
rej_Naive(sim_id) = mean( abs(thetahat_Naive - theta0)>1.96*sqrt(Vhat_Naive/n));
Length_Naive(sim_id) = mean(1.96*sqrt(Vhat_Naive/n));
MISE_Naive(sim_id) = mean(ISE_Naive);
Track_K_Naive(sim_id) = mean(K_Naive);
Track_L_Naive(sim_id) = mean(L_Naive);

StDev_TU(sim_id) = std(theta0 - thetahat_Naive);
Bias_TU(sim_id) = mean(theta0 - thetahat_Naive);
rej_TU(sim_id) = mean( abs( theta0 > ub_TU | theta0 < lb_TU));
Length_TU(sim_id) = mean(ub_TU - lb_TU);
MISE_TU(sim_id) = mean(ISE_Naive);
Track_K_TU(sim_id) = mean(K_Naive);
Track_L_TU(sim_id) = mean(L_Naive);

StDev_Oracle(sim_id) = std(theta0 - thetahat_Oracle);
Bias_Oracle(sim_id) = mean(theta0 - thetahat_Oracle);
rej_Oracle(sim_id) = mean( abs(thetahat_Oracle - theta0)>1.96*sqrt(Vhat_Oracle/n));
Length_Oracle(sim_id) = mean(1.96*sqrt(Vhat_Oracle/n));
MISE_Oracle(sim_id) = mean(ISE_Oracle);
Track_K_Oracle(sim_id) = mean(K_Oracle);
Track_L_Oracle(sim_id) = mean(L_Oracle);

%MAD_OLS(sim_id) = (median(abs(theta0 - thetahat_OLS)));
StDev_OLS(sim_id) = std(theta0 - thetahat_OLS);
Bias_OLS(sim_id) = mean(theta0 - thetahat_OLS);
rej_OLS(sim_id) = mean( abs(thetahat_OLS - theta0)>1.96*sqrt(Vhat_OLS/n));
Length_OLS(sim_id) = mean(1.96*sqrt(Vhat_OLS/n));
MISE_OLS(sim_id) = mean(ISE_OLS);
MISE_OLS(sim_id) = mean(ISE_OLS);
Track_K_OLS(sim_id) = mean(K_OLS);
Track_L_OLS(sim_id) = mean(L_OLS);
     
     display('--------------------------------------------------------------------------------------')
     display('--------------------------------------------------------------------------------------')
     display(['Simulation # ',num2str(sim_id)])
     display(['Simulation Parameters:  ','n = ',num2str(n), ' s0 = ',num2str(s0), ' L = ', num2str(L)])
     display(['Total Replications = ',num2str(sim_max)])
     display('----------------------------------------------------------------------------------------')
     display(' Estimator             MISE     StDev         Bias        5% RejRate          IntLength    K')     
     display('----------------------------------------------------------------------------------------')
     display([' PND Span            ', num2str([MISE_Blanket(sim_id),StDev_Blanket(sim_id), Bias_Blanket(sim_id), rej_Blanket(sim_id), Length_Blanket(sim_id),Track_K_Blanket(sim_id)] , '%+1.4f \t')])
     display([' Naive               ', num2str([MISE_Naive(sim_id),StDev_Naive(sim_id), Bias_Naive(sim_id), rej_Naive(sim_id), Length_Naive(sim_id),Track_K_Naive(sim_id)] , '%+1.4f \t')])
     display([' Oracle              ', num2str([MISE_Oracle(sim_id), StDev_Oracle(sim_id), Bias_Oracle(sim_id), rej_Oracle(sim_id),Length_Oracle(sim_id),Track_K_Oracle(sim_id)] , '%+1.4f \t')])
     display([' TU                  ', num2str([MISE_TU(sim_id), StDev_TU(sim_id), Bias_TU(sim_id), rej_TU(sim_id),Length_TU(sim_id),Track_K_TU(sim_id)] , '%+1.4f \t')])

     if L < n
     display([' OLS                 ', num2str([MISE_OLS(sim_id),StDev_OLS(sim_id), Bias_OLS(sim_id), rej_OLS(sim_id),Length_OLS(sim_id),Track_K_OLS(sim_id)] , '%+1.4f \t')])
     end
     display('----------------------------------------------------------------------------------------')   


   
  
     
end

XX=n_vec;
XXlabel=100:100:500;
figure('Position',[230,250,970,1010]) 
subplot(4,2,1)
hold on, plot(XX,StDev_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,StDev_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,StDev_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,StDev_Naive,'sk-','linewidth',1,'markersize',6)
if L < n, hold on, plot(XX,StDev_OLS,'sk-.','linewidth',1,'markersize',6), end
title('Standard Deviation', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid


subplot(4,2,5)
hold on, plot(XX,Track_K_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_K_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,Track_K_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_K_Naive,'sk-','linewidth',1,'markersize',6)
if L < n, hold on, plot(XX,Track_K_OLS,'sk-.','linewidth',1,'markersize',6), end
title('Number Selected (K)', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid


subplot(4,2,6)
hold on, plot(XX,Track_L_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_L_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,Track_L_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_L_Naive,'sk-','linewidth',1,'markersize',6)
%if L < n, hold on, plot(XX,Track_L_OLS,'sk-.','linewidth',1,'markersize',6), end
title('Number Selected (L)', 'fontsize',24)
xlim([50,550]), ylim([0,7])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,2)
hold on, plot(XX,Bias_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Bias_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,Bias_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,Bias_Naive,'sk-','linewidth',1,'markersize',6)
if L < n, hold on, plot(XX,Bias_OLS,'sk-.','linewidth',1,'markersize',6), end 
title('Bias', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,3)
hold on, plot(XX,Length_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Length_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,Length_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,Length_Naive,'sk-','linewidth',1,'markersize',6)
if L < n, hold on, plot(XX,Length_OLS,'sk-.','linewidth',1,'markersize',6), end 
title('Interval Length', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,4)  
hold on, plot(XX,rej_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,rej_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,rej_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,rej_Naive,'sk-','linewidth',1,'markersize',6)
if L < n, hold on, plot(XX,rej_OLS,'sk-.','linewidth',1,'markersize',6), end 
title('Rejection Frequency', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,7:8)
hold on, plot(XX,MISE_Oracle,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,MISE_Blanket,'sk-','linewidth',3,'markersize',6) 
hold on, plot(XX,MISE_TU,'sk:','linewidth',1,'markersize',6) 
hold on, plot(XX,MISE_Naive,'sk-','linewidth',1,'markersize',6)
if L<n, hold on, plot(XX,MISE_OLS,'sk-.','linewidth',1,'markersize',6), end 
if L<n, legend({'Oracle','PND Span','TU','Naive','OLS'},'fontsize',20,'Position',[0.6250 0.1200 0.2550 0.1550])
else legend({'Oracle','PND Span','TU','Naive'},'fontsize',20,'Position',[0.6250 0.1200 0.2550 0.1550]), end
title('Integrated Squared Error', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18,'Position',[0.1300 0.1100 0.335 0.1550])
grid

set(gcf,'PaperPositionMode','auto')
if L < n   
    print('Add_Sep_Sim_L=n_over_2','-dpng')
        savefig('fig_Add_Sep_Sim_L=n_over_2')

else
    print('Add_Sep_Sim_L=2n','-dpng')
        savefig('fig_Add_Sep_Sim_L=2n')

end




end

%Display simulation end time
disp('Simulation end time:')
disp(datetime('now'))
disp(['Total duration: ',num2str(toc), ' seconds'])

%figure, for jj=1:6, subplot(2,3,jj), plot(z(:,jj),x,'ko'),xlabel(['z_',num2str(jj)],'fontsize',24),ylabel('x','fontsize',24),end

