
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Simulation for "Estimation and Inference in Additively Separable
%Conditional Expectation Models with a High Dimensional Component"
%Comparison of Span (also called Blanket in this code) first stage to other Phi_K

%y = g0(x) + h0(z) + e

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Display Start time
disp('Simulation start time:')
disp(datetime('now'))

%Basic Simulation Parameters
rng(1);
tic
n_vec = 100:50:500;
sim_id_max=length(n_vec);
L_id_max=2;
sim_max=1000;

%Loop over simulation designs
for L_id = 1
     
%Preassign Output Matrices

Vhat_Altspline = zeros(sim_max,1);
Vhat_Simple = zeros(sim_max,1);
Vhat_Hermite = zeros(sim_max,1);
Vhat_Blanket = zeros(sim_max,1);
Vhat_BlanketRelaxed = zeros(sim_max,1);

thetahat_Altspline = zeros(sim_max,1);
thetahat_Hermite = zeros(sim_max,1);
thetahat_Simple = zeros(sim_max,1);
thetahat_Blanket = zeros(sim_max,1);
thetahat_BlanketRelaxed = zeros(sim_max,1);

ISE_Altspline = zeros(sim_max,1);
ISE_Hermite = zeros(sim_max,1);
ISE_Simple = zeros(sim_max,1);
ISE_Blanket = zeros(sim_max,1);
ISE_BlanketRelaxed = zeros(sim_max,1);

theta0=zeros(sim_max,1);

StDev_Blanket=zeros(sim_id_max,1);
StDev_BlanketRelaxed=zeros(sim_id_max,1);
StDev_Simple=zeros(sim_id_max,1);
StDev_Altspline=zeros(sim_id_max,1);
StDev_Hermite=zeros(sim_id_max,1);

Bias_Blanket=zeros(sim_id_max,1);
Bias_BlanketRelaxed=zeros(sim_id_max,1);
Bias_Simple=zeros(sim_id_max,1);
Bias_Altspline=zeros(sim_id_max,1);
Bias_Hermite=zeros(sim_id_max,1);

rej_Blanket=zeros(sim_id_max,1);
rej_BlanketRelaxed=zeros(sim_id_max,1);
rej_Simple=zeros(sim_id_max,1);
rej_Altspline=zeros(sim_id_max,1);
rej_Hermite=zeros(sim_id_max,1);

Length_Blanket=zeros(sim_id_max,1);
Length_BlanketRelaxed=zeros(sim_id_max,1);
Length_Simple=zeros(sim_id_max,1);
Length_Altspline=zeros(sim_id_max,1);
Length_Hermite=zeros(sim_id_max,1);

MISE_Hermite=zeros(sim_id_max,1);
MISE_BlanketRelaxed=zeros(sim_id_max,1);
MISE_Altspline=zeros(sim_id_max,1);
MISE_Simple=zeros(sim_id_max,1);
MISE_Blanket=zeros(sim_id_max,1);

K_Simple=zeros(sim_max,1);
K_Altspline=zeros(sim_max,1);
K_Hermite=zeros(sim_max,1);
K_Blanket=zeros(sim_max,1);
K_BlanketRelaxed=zeros(sim_max,1);


L_Simple=zeros(sim_max,1);
L_Altspline=zeros(sim_max,1);
L_Hermite=zeros(sim_max,1);
L_Blanket=zeros(sim_max,1);
L_BlanketRelaxed=zeros(sim_max,1);

Track_K_Simple=zeros(sim_id_max,1);
Track_K_Altspline=zeros(sim_id_max,1);
Track_K_Hermite=zeros(sim_id_max,1);
Track_K_Blanket=zeros(sim_id_max,1);
Track_K_BlanketRelaxed=zeros(sim_id_max,1);

Track_L_Simple=zeros(sim_id_max,1);
Track_L_Altspline=zeros(sim_id_max,1);
Track_L_Hermite=zeros(sim_id_max,1);
Track_L_Blanket=zeros(sim_id_max,1);
Track_L_BlanketRelaxed=zeros(sim_id_max,1);

%Loop over sample sizes
for sim_id = 1:sim_id_max









for nsim = 1:sim_max

       %g0 Design
g0=@(x)   10*sin(x/10)-.5*sin(4*pi*x.*4.^(-x.^2));
n=n_vec(sim_id);
sigma_e=1;
sigma_v=1;
if L_id == 1, cL=.5; else cL=2; end
L=floor(n*cL);
s0=6;
gamma0=((.75).^(1:(L)).*abs((1:L)<=s0))';
beta0h = .5*((-.65).^(0:(L-1)).*abs((1:L)<=s0))'; %beta0h(6)=.25;
h0=@(z) z* beta0h ;   


    
    %Generate Data  
        v=randn(n,1)*sigma_v;
        vv=rand(n,1)/2;
        S = chol(toeplitz((.25).^(0:(L-1))));
        z=randn(n,L)*S;
        eta0=zeros(L,1); 
        
        %for jj=floor(s0/2):s0 
        %    eta0(jj) = .5;
        %end
        eta0(s0)=1;
        
        vvv = randn(n,1);
        %x= z*gamma0 + v;
        a_stair=12;w_stair=2.5;h_stair=.25;
        stair_step = @(x,h,w,a) h*( (tanh(a*x/w -  a*floor(x/w) - a*.5 ))./ (2*tanh(a /2)) + .5 + floor(x/w) ); 
        %figure, plot(-10:.1:10,stair_step((-10:.1:10),h_stair,w_stair,a_stair))
        
        
        %x_hmtpy=@(x,t)x.*t + stair_step(x,h_stair,w_stair,a_stair).*(1-t);
        %x= x_hmtpy(z*gamma0 + v,norminv(z*eta0));
        
        
        
        zz=-2*z*gamma0 + 1*v;
        tt=normcdf(z*eta0*10);
 x = 1.5*(.1*v+ .25 + -.5 *( (5*stair_step(zz,h_stair,w_stair,a_stair)+.5).*tt +  (5*stair_step(.5*zz.*abs(zz).^.25+1,h_stair,w_stair,a_stair)).*(1-tt)  )   );

        %x = (5*stair_step(zz,h_stair,w_stair,a_stair)-.35).*abs(tt<.05) +  (5*stair_step(zz,h_stair,w_stair,a_stair)+.25).*(1-tt).*abs(tt>.95) + z.*abs(tt<.95 & tt>.05);
        e=randn(n,1)*sigma_e.*.5.*(exp(.5*z*(.75.^((L-1):(-1):0)')));
        y = g0(x) + h0(z) + e;
        
        %figure, plot(z(:,6),x,'o')
        
        
        %Generate functional of interest   
        x_a_unif = norminv(.01:.01:.99)';
        theta0(nsim)=ave_deriv(g0,x_a_unif);
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %ESTIMATION
        
        %z dictionary definition
        Q=z;

        %Lasso Steps
        [S_lasso_RF,~,~,~, ~, ~]=lasso_hetero(y,Q,.05,1.01); 
          
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Construct dictionaries

        
        %Blanket and Simple Dictionaries
        [p_Blanket,K_Blanket(nsim)]= generate_p(y,x,Q(:,S_lasso_RF));
        P_Blanket=[];for k=1:K_Blanket(nsim), P_Blanket=[P_Blanket,p_Blanket{k}(x)]; end %#ok
        
        p_Simple = p_Blanket; K_Simple(nsim) = K_Blanket(nsim); P_Simple = P_Blanket;
        
        p_BlanketRelaxed = p_Blanket; K_BlanketRelaxed(nsim) = K_Blanket(nsim); P_BlanketRelaxed = P_Blanket;
        
        
        
     %{   
        %Hermite Dictionary
        [p_Hermite,K_Hermite(nsim)]= generate_p_Hermite(y,x,Q(:,S_lasso_RF));
        P_Hermite=[];for k=1:K_Hermite(nsim), P_Hermite=[P_Hermite,p_Hermite{k}(x)]; end %#ok

        %}
        
        
        %Altspline (alternative spline) Dictionary
        %[p_Altspline,K_Altspline(nsim)]= generate_p_Altspline(y,x,Q(:,S_lasso_RF));
        %P_Altspline=[];for k=1:K_Altspline(nsim), P_Altspline=[P_Altspline,p_Altspline{k}(x)]; end %#ok
        p_Altspline = p_Blanket; K_Altspline(nsim) = K_Blanket(nsim);
        P_Altspline = qr(P_Blanket,0);
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-1:  Standard dictionary
    [S_lasso_FS_1,~,~,~, ~, ~]=lasso_hetero(x,Q,.05,1.01); 
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-2:  Standard dictionary
    S_lasso_FS_2=[];
    
    
    for k = 1:K_Blanket(nsim)
        [S_Simple_temp,~,~,~, ~, ~]=lasso_hetero(P_Blanket(:,k),Q,.05/K_Blanket(nsim),1.01 ); 
        if isempty(S_lasso_FS_2), S_lasso_FS_2 = S_Simple_temp;
        else
        S_lasso_FS_2 = S_lasso_FS_2 | S_Simple_temp ;
        end
    end
    

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-3:  Standard dictionary
    S_lasso_FS_3=[];
    
    zeta = P_Blanket\Q;
    for j = 1:L
        [S_Blanket_temp,~,~,~, ~, ~]=lasso_hetero(P_Blanket*zeta(:,j),Q,.05,1.01*sqrt(K_Blanket(nsim)) ); 
        if isempty(S_lasso_FS_3), S_lasso_FS_3 = S_Blanket_temp;
        else
        S_lasso_FS_3 = S_lasso_FS_3 | S_Blanket_temp ;
        end
    end
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-3-Relaxed:  Standard dictionary
    S_lasso_FS_3Relaxed=[];
    
    zeta = P_Blanket\Q;
    for j = 1:L
        [S_Blanket_temp,~,~,~, ~, ~]=lasso_hetero(P_Blanket*zeta(:,j),Q,.05/K_Blanket(nsim),1.01 ); 
        if isempty(S_lasso_FS_3Relaxed), S_lasso_FS_3Relaxed = S_Blanket_temp;
        else
        S_lasso_FS_3Relaxed = S_lasso_FS_3Relaxed | S_Blanket_temp ;
        end
    end
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Form Unions
    S_lasso_RF = find(S_lasso_RF ~=0);
    S_lasso_FS_1 = find(S_lasso_FS_1 ~=0);
    S_lasso_FS_2 = find(S_lasso_FS_2 ~=0);
    S_lasso_FS_3 = find(S_lasso_FS_3 ~=0);
    S_lasso_FS_12 = union(S_lasso_FS_1, S_lasso_FS_2); 
    S_lasso_FS = union(S_lasso_FS_12, S_lasso_FS_3); 
    S_lasso_Blanket = union(S_lasso_RF,S_lasso_FS);
    S_lasso_FS_3Relaxed = find(S_lasso_FS_3Relaxed~=0);
    S_lasso_BlanketRelaxed=union(S_lasso_Blanket,S_lasso_FS_3Relaxed);
    S_lasso_Simple = union(S_lasso_RF,S_lasso_FS_2);
    
    %Reduced dictionary:  Blanket
    Q_Blanket=Q(:,S_lasso_Blanket);
    L_Blanket(nsim) = length(S_lasso_Blanket);
    
    %Reduced dictionary:  Blanket
    Q_BlanketRelaxed=Q(:,S_lasso_BlanketRelaxed);
    L_BlanketRelaxed(nsim) = length(S_lasso_BlanketRelaxed);
    
    %Reduced dictionary:  Simple
    Q_Simple=Q(:,S_lasso_Simple);
    L_Simple(nsim) = length(S_lasso_Simple);
    
    if L_BlanketRelaxed(nsim) < L_Blanket(nsim), keyboard, end
    
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-2:  Altspline dictionary
    S_lasso_FS_Altspline=[];
    
    
    
    for k = 1:K_Altspline(nsim)
        [S_Simple_temp,~,~,~, ~, ~]=lasso_hetero(P_Altspline(:,k),Q,.05/K_Altspline(nsim),1.01 ); 
        if isempty(S_lasso_FS_Altspline), S_lasso_FS_Altspline = S_Simple_temp;
        else
        S_lasso_FS_Altspline = S_lasso_FS_Altspline | S_Simple_temp ;
        end
    end
    
    %Reduced dictionary:  Altspline
    S_lasso_FS_Altspline = find(S_lasso_FS_Altspline ~=0);
    Q_Altspline=Q(:,union(S_lasso_FS_Altspline,S_lasso_RF));
    L_Altspline(nsim) = length(union(S_lasso_FS_Altspline,S_lasso_RF));
    
    %}
    
    %{
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %First stage PHI-2:  Hermite dictionary
    S_lasso_FS_Hermite=[];
    
    
    for k = 1:K_Hermite(nsim)
        [S_Simple_temp,~,~,~, ~, ~]=lasso_hetero(P_Hermite(:,k),Q,.05/K_Hermite(nsim),1.01 ); 
        if isempty(S_lasso_FS_Hermite), S_lasso_FS_Hermite = S_Simple_temp;
        else
        S_lasso_FS_Hermite = S_lasso_FS_Hermite | S_Simple_temp ;
        end
    end
    
   
    %Reduced dictionary:  Hermite
    S_lasso_FS_Hermite = find(S_lasso_FS_Hermite~=0);
    Q_Hermite=Q(:,union(S_lasso_FS_Hermite,S_lasso_RF));
    L_Hermite(nsim) = length(union(S_lasso_FS_Hermite,S_lasso_RF));
    
    
    
    %}
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Post Model Selection Estimation
    
    

    %Blanket Post - Double Selection
    [ghat_Blanket,thetahat_Blanket(nsim),Vhat_Blanket(nsim)] = nonpar_simple(y,x,p_Blanket,K_Blanket(nsim),Q_Blanket); 
    
    %Blanket Post - Double Selection
    [ghat_BlanketRelaxed,thetahat_BlanketRelaxed(nsim),Vhat_BlanketRelaxed(nsim)] = nonpar_simple(y,x,p_Blanket,K_Blanket(nsim),Q_BlanketRelaxed); 
    
    %Simple -- Double Selection
    [ghat_Simple, thetahat_Simple(nsim), Vhat_Simple(nsim)] = nonpar_simple(y,x,p_Simple,K_Simple(nsim),Q_Simple);

    %Simple - Alternative Spline Basis
    [ghat_Altspline,thetahat_Altspline(nsim), Vhat_Altspline(nsim)] = nonpar_simple(y,x,p_Altspline,K_Altspline(nsim),Q_Altspline); 
    
    %Simple Hermite Polynomials
    %[ghat_Hermite,thetahat_Hermite(nsim),Vhat_Hermite(nsim)] = nonpar_simple(y,x,p_Hermite,K_Hermite(nsim),Q_Hermite); 
    

    ISE_Blanket(nsim) = mean((ghat_Blanket(x) - g0(x)).^2);
    ISE_BlanketRelaxed(nsim) = mean((ghat_BlanketRelaxed(x) - g0(x)).^2);
    ISE_Simple(nsim) = mean((ghat_Simple(x) - g0(x)).^2);
    ISE_Altspline(nsim) = mean((ghat_Altspline(x) - g0(x)).^2);
    %ISE_Hermite(nsim) = mean((ghat_Hermite(x) - g0(x)).^2);

end


StDev_Blanket(sim_id) = std(theta0 - thetahat_Blanket);
Bias_Blanket(sim_id) = mean(theta0 - thetahat_Blanket);
rej_Blanket(sim_id) = mean( abs(thetahat_Blanket - theta0)>1.96*sqrt(Vhat_Blanket/n));
Length_Blanket(sim_id) = mean(1.96*sqrt(Vhat_Blanket/n));
MISE_Blanket(sim_id) = mean(ISE_Blanket);
Track_K_Blanket(sim_id) = mean(K_Blanket);
Track_L_Blanket(sim_id) = mean(L_Blanket);

StDev_BlanketRelaxed(sim_id) = std(theta0 - thetahat_BlanketRelaxed);
Bias_BlanketRelaxed(sim_id) = mean(theta0 - thetahat_BlanketRelaxed);
rej_BlanketRelaxed(sim_id) = mean( abs(thetahat_BlanketRelaxed - theta0)>1.96*sqrt(Vhat_BlanketRelaxed/n));
Length_BlanketRelaxed(sim_id) = mean(1.96*sqrt(Vhat_BlanketRelaxed/n));
MISE_BlanketRelaxed(sim_id) = mean(ISE_BlanketRelaxed);
Track_K_BlanketRelaxed(sim_id) = mean(K_BlanketRelaxed);
Track_L_BlanketRelaxed(sim_id) = mean(L_BlanketRelaxed);

StDev_Simple(sim_id) = std(theta0 - thetahat_Simple);
Bias_Simple(sim_id) = mean(theta0 - thetahat_Simple);
rej_Simple(sim_id) = mean( abs(thetahat_Simple - theta0)>1.96*sqrt(Vhat_Simple/n));
Length_Simple(sim_id) = mean(1.96*sqrt(Vhat_Simple/n));
MISE_Simple(sim_id) = mean(ISE_Simple);
Track_K_Simple(sim_id) = mean(K_Simple);
Track_L_Simple(sim_id) = mean(L_Simple);

StDev_Altspline(sim_id) = std(theta0 - thetahat_Altspline);
Bias_Altspline(sim_id) = mean(theta0 - thetahat_Altspline);
rej_Altspline(sim_id) = mean( abs(thetahat_Altspline - theta0)>1.96*sqrt(Vhat_Altspline/n));
Length_Altspline(sim_id) = mean(1.96*sqrt(Vhat_Altspline/n));
MISE_Altspline(sim_id) = mean(ISE_Altspline);
Track_K_Altspline(sim_id) = mean(K_Altspline);
Track_L_Altspline(sim_id) = mean(L_Altspline);

StDev_Hermite(sim_id) = std(theta0 - thetahat_Hermite);
Bias_Hermite(sim_id) = mean(theta0 - thetahat_Hermite);
rej_Hermite(sim_id) = mean( abs(thetahat_Hermite - theta0)>1.96*sqrt(Vhat_Hermite/n));
Length_Hermite(sim_id) = mean(1.96*sqrt(Vhat_Hermite/n));
MISE_Hermite(sim_id) = mean(ISE_Hermite);
Track_K_Hermite(sim_id) = mean(K_Hermite);
Track_L_Hermite(sim_id) = mean(L_Hermite);


%Display results

     display('--------------------------------------------------------------------------------------')
     display('--------------------------------------------------------------------------------------')
     display(['Simulation # ',num2str(sim_id)])
     display(['Simulation Parameters:  ','n = ',num2str(n), ' s0 = ',num2str(s0), ' L = ', num2str(L)])
     display(['Total Replications = ',num2str(sim_max)])
     display('----------------------------------------------------------------------------------------')
     display(' Estimator             MISE     StDev         Bias        5% RejRate          IntLength    L')     
     display('----------------------------------------------------------------------------------------')
     display([' Span Conservative    ', num2str([MISE_Blanket(sim_id),StDev_Blanket(sim_id), Bias_Blanket(sim_id), rej_Blanket(sim_id), Length_Blanket(sim_id),Track_L_Blanket(sim_id)] , '%+1.4f \t')])
     display([' Span                 ', num2str([MISE_BlanketRelaxed(sim_id),StDev_BlanketRelaxed(sim_id), Bias_BlanketRelaxed(sim_id), rej_BlanketRelaxed(sim_id), Length_BlanketRelaxed(sim_id),Track_L_BlanketRelaxed(sim_id)] , '%+1.4f \t')])
     display([' Simple               ', num2str([MISE_Simple(sim_id),StDev_Simple(sim_id), Bias_Simple(sim_id), rej_Simple(sim_id), Length_Simple(sim_id),Track_L_Simple(sim_id)] , '%+1.4f \t')])
     display([' Alt Spline           ', num2str([MISE_Altspline(sim_id), StDev_Altspline(sim_id), Bias_Altspline(sim_id), rej_Altspline(sim_id),Length_Altspline(sim_id),Track_L_Altspline(sim_id)] , '%+1.4f \t')])
     %display([' Hermite             ', num2str([MISE_Hermite(sim_id), StDev_Hermite(sim_id), Bias_Hermite(sim_id), rej_Hermite(sim_id),Length_Hermite(sim_id),Track_K_Hermite(sim_id)] , '%+1.4f \t')])
     display('----------------------------------------------------------------------------------------')   


     
   
end


%Plot Results
XX=n_vec;
XXlabel=100:100:500;
figure('Position',[230,250,970,1010]) 
subplot(4,2,1)
hold on, plot(XX,StDev_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,StDev_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,StDev_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,StDev_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Standard Deviation', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid


subplot(4,2,5)
hold on, plot(XX,Track_K_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_K_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_K_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,Track_K_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Number Selected (K)', 'fontsize',24)
xlim([0,550]), 
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,2)
hold on, plot(XX,Bias_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Bias_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,Bias_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,Bias_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Bias', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,3)
hold on, plot(XX,Length_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Length_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,Length_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,Length_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Interval Length', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,4)  
hold on, plot(XX,rej_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,rej_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,rej_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,rej_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Rejection Frequency', 'fontsize',24)
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,6)  
hold on, plot(XX,Track_L_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_L_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,Track_L_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,Track_L_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Number Selected (L)', 'fontsize',24)
xlim([50,550]), ylim([0,7])
set(gca,'XTick',(XXlabel),'fontsize',18)
grid

subplot(4,2,7:8)
hold on, plot(XX,MISE_Simple,'sk--','linewidth',1,'markersize',6) 
hold on, plot(XX,MISE_Blanket,'sk-','linewidth',1,'markersize',6) 
hold on, plot(XX,MISE_BlanketRelaxed,'sk-','linewidth',3,'markersize',6)
hold on, plot(XX,MISE_Altspline,'sk:','linewidth',1,'markersize',6) 
title('Integrated Squared Error', 'fontsize',24)
legend({'PND Simple','PND Span Conservative','PND Span','PND Alt-Spline Simple'},'fontsize',20,'Position',[0.6250 0.1200 0.2550 0.1550]), 
%legend({'PND Simple','PND Blanket','PND Alternative Spline','PND Hermite'},'fontsize',20,'Position',[0.6250 0.1200 0.2550 0.2550]), 
xlim([50,550])
set(gca,'XTick',(XXlabel),'fontsize',18,'Position',[0.1300 0.1100 0.335 0.1550])
grid

%Save Results

set(gcf,'PaperPositionMode','auto')
if L < n   
    print('Add_Sep_Sim_L=n_over_2_blanket_vs_simple_altspline','-dpng')
    savefig('fig_Add_Sep_Sim_L=n_over_2_blanket_vs_simple_altspline')
else
    print('Add_Sep_Sim_L=2n_blanket_vs_simple_altspline','-dpng')
    savefig('fig_Add_Sep_Sim_L=2n_blanket_vs_simple_altspline')
end
%}



end

%Display simulation end time
disp('Simulation end time:')
disp(datetime('now'))
disp(['Total duration: ',num2str(toc), ' seconds'])


